==> firebase_repository-1.0.34.tar.gz: lib/src/entities/dieta_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class DietaEntity extends Equatable{
  final String uuid;
  final bool activo;
  final int agua;
  final double calcio;
  final double costo;
  final double fdn;
  final double fosforo;
  final double mcal;
  final double ms;
  final String nombre;
  final double porcentaje;
  final double prot;
  final double talcual;
  final String type;
  final List<dynamic> detalles;

  DietaEntity(this.uuid, this.activo, this.agua, this.calcio, this.costo,
      this.fdn, this.fosforo, this.mcal, this.ms, this.nombre, this.porcentaje,
      this.prot, this.talcual, this.type, this.detalles);


  Map<String, Object> toJson(){
    return {
      'activo': this.activo,
      'agua': this.agua,
      'calcio': this.calcio,
      'costo': this.costo,
      'fdn': this.fdn,
      'fosforo': this.fosforo,
      'mcal': this.mcal,
      'ms': this.ms,
      'nombre': this.nombre,
      'porcerntaje': this.porcentaje,
      'prot': this.prot,
      'talcual': this.talcual,
      'type': this.type,
      'detalles': this.detalles
    };
  }


  @override
  String toString() {
    return 'DietaEntity{uuid: $uuid, activo: $activo, agua: $agua, calcio: $calcio, costo: $costo, fdn: $fdn, fosforo: $fosforo, mcal: $mcal, ms: $ms, nombre: $nombre, porcentaje: $porcentaje, prot: $prot, talcual: $talcual, type: $type, detalles: $detalles}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is DietaEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              activo == other.activo &&
              agua == other.agua &&
              calcio == other.calcio &&
              costo == other.costo &&
              fdn == other.fdn &&
              fosforo == other.fosforo &&
              mcal == other.mcal &&
              ms == other.ms &&
              nombre == other.nombre &&
              porcentaje == other.porcentaje &&
              prot == other.prot &&
              talcual == other.talcual &&
              type == other.type &&
              detalles == other.detalles;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      activo.hashCode ^
      agua.hashCode ^
      calcio.hashCode ^
      costo.hashCode ^
      fdn.hashCode ^
      fosforo.hashCode ^
      mcal.hashCode ^
      ms.hashCode ^
      nombre.hashCode ^
      porcentaje.hashCode ^
      prot.hashCode ^
      talcual.hashCode ^
      type.hashCode ^
      detalles.hashCode;

  static DietaEntity fromJson(Map<String, Object> json){
    return DietaEntity(
      json['uuid'] as String,
      json['activo'] as bool,
      json['agua'] as int,
      json['calcio'] as double,
      json['costo'] as double,
      json['fdn'] as double,
      json['fosforo'] as double,
      json['mcal'] as double,
      json['ms'] as double,
      json['nombre'] as String,
      json['porcentaje'] as double,
      json['prot'] as double,
      json['talcual'] as double,
      json['type'] as String,
      json['detalles'] as List<dynamic>
    );
  }

  static DietaEntity fromSnapshot(DocumentSnapshot snap){
    return DietaEntity(
      snap.documentID,
      snap.data['activo'],
      int.parse(snap.data['agua'].toString()),
      double.parse(snap.data['calcio'].toString()),
      double.parse(snap.data['costo'].toString()),
      double.parse(snap.data['fdn'].toString()),
      double.parse(snap.data['fosforo'].toString()),
      double.parse(snap.data['mcal'].toString()),
      double.parse(snap.data['ms'].toString()),
      snap.data['nombre'],
      double.parse(snap.data['porcentaje'].toString()),
      double.parse(snap.data['prot'].toString()),
      double.parse(snap.data['talcual'].toString()),
      snap.data['type'],
      snap.data['detalle']
    );
  }

  Map<String, Object> toDocument(){
    return{
      'activo': this.activo,
      'agua': this.agua,
      'calcio': this.calcio,
      'costo': this.costo,
      'fdn': this.fdn,
      'fosforo': this.fosforo,
      'mcal': this.mcal,
      'ms': this.ms,
      'nombre': this.nombre,
      'porcerntaje': this.porcentaje,
      'prot': this.prot,
      'talcual': this.talcual,
      'type': this.type,
      'detalle' : this.detalles
    };
  }



}

==> firebase_repository-1.0.48.tar.gz: lib/src/entities/dieta_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class DietaEntity extends Equatable{
  final String uuid;
  final bool activo;
  final double agua;
  final double calcio;
  final double costo;
  final double fdn;
  final double fosforo;
  final double mcal;
  final double ms;
  final String nombre;
  final double porcentaje;
  final double prot;
  final double talcual;
  final String type;
  final List<dynamic> detalles;

  DietaEntity(this.uuid, this.activo, this.agua, this.calcio, this.costo,
      this.fdn, this.fosforo, this.mcal, this.ms, this.nombre, this.porcentaje,
      this.prot, this.talcual, this.type, this.detalles);


  Map<String, Object> toJson(){
    return {
      'activo': this.activo,
      'agua': this.agua,
      'calcio': this.calcio,
      'costo': this.costo,
      'fdn': this.fdn,
      'fosforo': this.fosforo,
      'mcal': this.mcal,
      'ms': this.ms,
      'nombre': this.nombre,
      'porcerntaje': this.porcentaje,
      'prot': this.prot,
      'talcual': this.talcual,
      'type': this.type,
      'detalles': this.detalles
    };
  }


  @override
  String toString() {
    return 'DietaEntity{uuid: $uuid, activo: $activo, agua: $agua, calcio: $calcio, costo: $costo, fdn: $fdn, fosforo: $fosforo, mcal: $mcal, ms: $ms, nombre: $nombre, porcentaje: $porcentaje, prot: $prot, talcual: $talcual, type: $type, detalles: $detalles}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is DietaEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              activo == other.activo &&
              agua == other.agua &&
              calcio == other.calcio &&
              costo == other.costo &&
              fdn == other.fdn &&
              fosforo == other.fosforo &&
              mcal == other.mcal &&
              ms == other.ms &&
              nombre == other.nombre &&
              porcentaje == other.porcentaje &&
              prot == other.prot &&
              talcual == other.talcual &&
              type == other.type &&
              detalles == other.detalles;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      activo.hashCode ^
      agua.hashCode ^
      calcio.hashCode ^
      costo.hashCode ^
      fdn.hashCode ^
      fosforo.hashCode ^
      mcal.hashCode ^
      ms.hashCode ^
      nombre.hashCode ^
      porcentaje.hashCode ^
      prot.hashCode ^
      talcual.hashCode ^
      type.hashCode ^
      detalles.hashCode;

  static DietaEntity fromJson(Map<String, Object> json){
    return DietaEntity(
      json['uuid'] as String,
      json['activo'] as bool,
      json['agua'] as double,
      json['calcio'] as double,
      json['costo'] as double,
      json['fdn'] as double,
      json['fosforo'] as double,
      json['mcal'] as double,
      json['ms'] as double,
      json['nombre'] as String,
      json['porcentaje'] as double,
      json['prot'] as double,
      json['talcual'] as double,
      json['type'] as String,
      json['detalles'] as List<dynamic>
    );
  }

  static DietaEntity fromSnapshot(DocumentSnapshot snap){
    return DietaEntity(
      snap.documentID,
      snap.data['activo'],
      double.parse(snap.data['agua'].toString()),
      double.parse(snap.data['calcio'].toString()),
      double.parse(snap.data['costo'].toString()),
      double.parse(snap.data['fdn'].toString()),
      double.parse(snap.data['fosforo'].toString()),
      double.parse(snap.data['mcal'].toString()),
      double.parse(snap.data['ms'].toString()),
      snap.data['nombre'],
      double.parse(snap.data['porcentaje'].toString()),
      double.parse(snap.data['prot'].toString()),
      double.parse(snap.data['talcual'].toString()),
      snap.data['type'],
      snap.data['detalle']
    );
  }

  Map<String, Object> toDocument(){
    return{
      'activo': this.activo,
      'agua': this.agua,
      'calcio': this.calcio,
      'costo': this.costo,
      'fdn': this.fdn,
      'fosforo': this.fosforo,
      'mcal': this.mcal,
      'ms': this.ms,
      'nombre': this.nombre,
      'porcerntaje': this.porcentaje,
      'prot': this.prot,
      'talcual': this.talcual,
      'type': this.type,
      'detalle' : this.detalles
    };
  }



}
